# DABench Task 490 - What is the mean percentage of graduates in the field of Engineering?

## Task Description

What is the mean percentage of graduates in the field of Engineering?

## Concepts

Summary Statistics

## Data Description

Dataset file: `percent-bachelors-degrees-women-usa.csv`

The data is available in the `train.csv` file in the public directory.

## Constraints

Calculate the mean value using all available data points in the field of Engineering. Round the mean value to two decimal places.

## Files

- `train.csv` - The training data
- `sample_submission.csv` - A sample submission file in the correct format

## Submission Format

Submit a CSV with columns `id,answer`, containing one row. In the `answer` cell include:
@mean_value[number]

"number" is between 0 and 100, rounded to two decimal places.

## Evaluation

Submissions are evaluated on **exact match** with the ground truth answer (with tolerance of 0.01 for floating-point values).

## Goal

Provide the correct answer in the specified format.

## Difficulty Level

Easy
